@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
  /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,9 +34,7 @@
 #include <com/sun/star/ui/dialogs/ExecutableDialogResults.hpp>
 #include <com/sun/star/ucb/XSimpleFileAccess.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
-#ifndef _COM_SUN_STAR_UTIL_XCloseBroadcaster_HPP_
 #include <com/sun/star/util/XCloseBroadcaster.hpp>
-#endif
 #include <com/sun/star/frame/XComponentLoader.hpp>
 #include <com/sun/star/frame/XLayoutManager.hpp>
 #include <osl/time.h>
@@ -837,3 +836,5 @@ void HelpCloseListener::disposing( const EventObject& ) throw ( RuntimeException
 {
     mrXFrame = NULL;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
